# Generating SBOMs
### On this page
  * [Requirements for SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#requirements-for-sboms)
  * [Methods for Generating SBOMs](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#methods-for-generating-sboms)
  * [Centralized Methods](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#centralized-methods)
  * [Decentralized Methods](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#decentralized-methods)
  * [Generating SBOMs in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#generating-sboms-in-your-ci/cd-pipeline)
  * [CycloneDX](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#cyclonedx)
  * [SPDX](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#spdx)
  * [Additional Resources](https://help.sap.com/docs/leanix/ea/generating-sboms?version=CLOUD#additional-resources)


Explore the requirements for SBOM files and get an overview of the methods for generating them.
